@@ -23,7 +23,7 @@ from model_clone.utils import (
 
 class CloneMixin(object):
 
-    """CloneMixin mixin to duplicate an object using the model cls.
+    """CloneMixin mixin to duplicate an object using the model's class.
 
     :param _clone_fields: Restricted List of fields to copy from the instance.
     :type _clone_fields: collections.Iterable
@@ -298,7 +298,7 @@ class CloneMixin(object):
 
     @staticmethod
     def _create_copy_of_instance(instance, using=None, force=False, sub_clone=False):
-        """Create a copy of an instance
+        """Create a copy of a model instance.
 
         :param instance: The instance to be duplicated.
         :type instance: `django.db.models.Model`
@@ -464,29 +464,13 @@ class CloneMixin(object):
                 ):
                     rel_object = getattr(self, f.name, None)
                     if rel_object:
-                        if hasattr(rel_object, "make_clone"):
-                            try:
-                                rel_object.make_clone(
-                                    attrs={f.remote_field.name: duplicate},
-                                    using=using,
-                                )
-                            except IntegrityError:
-                                rel_object.make_clone(
-                                    attrs={f.remote_field.name: duplicate},
-                                    save_new=False,
-                                    sub_clone=True,
-                                    using=using,
-                                )
-                        else:
-                            new_rel_object = CloneMixin._create_copy_of_instance(
-                                rel_object,
-                                force=True,
-                                sub_clone=True,
-                                using=using,
-                            )
-                            setattr(new_rel_object, f.remote_field.name, duplicate)
-
-                            new_rel_object.save(using=using)
+                        new_rel_object = CloneMixin._create_copy_of_instance(
+                            rel_object,
+                            force=True,
+                            sub_clone=True,
+                        )
+                        setattr(new_rel_object, f.remote_field.name, duplicate)
+                        new_rel_object.save(using=using)
 
         return duplicate
 
