@@ -20,6 +20,7 @@ from sample.models import (
     BookTag,
     Cover,
     Edition,
+    Ending,
     Furniture,
     House,
     Library,
@@ -27,6 +28,7 @@ from sample.models import (
     Product,
     Room,
     SaleTag,
+    Sentence,
     Tag,
 )
 
@@ -882,6 +884,18 @@ class CloneMixinTestCase(TestCase):
         ]
         self.assertEqual(errors, expected_errors)
 
+    def test_cloning_o2o_fields(self):
+        sentence = Sentence.objects.create(value="A really long sentence")
+        Ending.objects.create(sentence=sentence)
+
+        self.assertEqual(1, Sentence.objects.count())
+        self.assertEqual(1, Ending.objects.count())
+
+        clones = [sentence.make_clone() for _ in range(2)]
+
+        self.assertEqual(2, len(clones))
+        self.assertEqual(3, Sentence.objects.count())
+
 
 class CloneMixinTransactionTestCase(TransactionTestCase):
     def test_cloning_multiple_instances_doesnt_exceed_the_max_length(self):
